@@ -7,11 +7,11 @@ import excelrd
 def main():
     book = excelrd.open_workbook("namesdemo.xls")
 
-    print("The number of worksheets is {}".format(book.nsheets))
+    print(f"The number of worksheets is {book.nsheets}")
     print("Worksheet name(s): {}".format(", ".join(book.sheet_names())))
 
     sh = book.sheet_by_index(2)
-    print("{}: rows={}, cols={}".format(sh.name, sh.nrows, sh.ncols))
+    print(f"{sh.name}: rows={sh.nrows}, cols={sh.ncols}")
 
     for row_idx in range(sh.nrows):
         for col_idx in range(sh.ncols):
@@ -20,7 +20,7 @@ def main():
             if not cell.value:
                 continue
 
-            print("row={}, col={}, value={}".format(row_idx, col_idx, cell.value))
+            print(f"row={row_idx}, col={col_idx}, value={cell.value}")
 
 
 if __name__ == "__main__":
