@@ -252,7 +252,7 @@ def nearest_colour_index(colour_map, rgb, debug=0):
     return best_colourx
 
 
-class EqNeAttrs(object):
+class EqNeAttrs:
     """
     This mixin class exists solely so that :class:`Format`, :class:`Font`, and
     :class:`XF` objects can be compared by value of their attributes.
@@ -327,7 +327,7 @@ class Font(BaseObject, EqNeAttrs):
     italic = 0
 
     #: The name of the font. Example: ``"Arial"``.
-    name = UNICODE_LITERAL("")
+    name = ""
 
     #: 1 = Characters are struck out.
     struck_out = 0
@@ -370,7 +370,7 @@ def handle_font(book, data):
     k = len(book.font_list)
     if k == 4:
         f = Font()
-        f.name = UNICODE_LITERAL("Dummy Font")
+        f.name = "Dummy Font"
         f.font_index = k
         book.font_list.append(f)
         k += 1
@@ -462,7 +462,7 @@ class Format(BaseObject, EqNeAttrs):
     type = FUN
 
     #: The format string
-    format_str = UNICODE_LITERAL("")
+    format_str = ""
 
     def __init__(self, format_key, ty, format_str):
         self.format_key = format_key
@@ -536,29 +536,29 @@ for lo, hi, ty in fmt_code_ranges:
         std_format_code_types[x] = ty
 del lo, hi, ty, x
 
-date_chars = UNICODE_LITERAL("ymdhs")  # year, month/minute, day, hour, second
+date_chars = "ymdhs"  # year, month/minute, day, hour, second
 date_char_dict = {}
 for _c in date_chars + date_chars.upper():
     date_char_dict[_c] = 5
 del _c, date_chars
 
 skip_char_dict = {}
-for _c in UNICODE_LITERAL("$-+/(): "):
+for _c in "$-+/(): ":
     skip_char_dict[_c] = 1
 
 num_char_dict = {
-    UNICODE_LITERAL("0"): 5,
-    UNICODE_LITERAL("#"): 5,
-    UNICODE_LITERAL("?"): 5,
+    "0": 5,
+    "#": 5,
+    "?": 5,
 }
 
 non_date_formats = {
-    UNICODE_LITERAL("0.00E+00"): 1,
-    UNICODE_LITERAL("##0.0E+0"): 1,
-    UNICODE_LITERAL("General"): 1,
-    UNICODE_LITERAL("GENERAL"): 1,  # OOo Calc 1.1.4 does this.
-    UNICODE_LITERAL("general"): 1,  # pyExcelerator 0.6.3 does this.
-    UNICODE_LITERAL("@"): 1,
+    "0.00E+00": 1,
+    "##0.0E+0": 1,
+    "General": 1,
+    "GENERAL": 1,  # OOo Calc 1.1.4 does this.
+    "general": 1,  # pyExcelerator 0.6.3 does this.
+    "@": 1,
 }
 
 fmt_bracketed_sub = re.compile(r"\[[^]]*\]").sub
@@ -584,16 +584,16 @@ def is_date_format_string(book, fmt):
 
     for c in fmt:
         if state == 0:
-            if c == UNICODE_LITERAL('"'):
+            if c == '"':
                 state = 1
-            elif c in UNICODE_LITERAL(r"\_*"):
+            elif c in r"\_*":
                 state = 2
             elif c in skip_char_dict:
                 pass
             else:
                 s += c
         elif state == 1:
-            if c == UNICODE_LITERAL('"'):
+            if c == '"':
                 state = 0
         elif state == 2:
             # Ignore char after backslash, underscore or asterisk
@@ -885,7 +885,12 @@ def handle_xf(self, data):
             pkd_brdbkg3,
         ) = unpack(unpack_fmt, data[0:20])
         upkbits(
-            xf.protection, pkd_type_par, ((0, 0x01, "cell_locked"), (1, 0x02, "formula_hidden"),)
+            xf.protection,
+            pkd_type_par,
+            (
+                (0, 0x01, "cell_locked"),
+                (1, 0x02, "formula_hidden"),
+            ),
         )
         upkbits(
             xf,
@@ -902,12 +907,20 @@ def handle_xf(self, data):
         upkbits(
             xf.alignment,
             pkd_align1,
-            ((0, 0x07, "hor_align"), (3, 0x08, "text_wrapped"), (4, 0x70, "vert_align"),),
+            (
+                (0, 0x07, "hor_align"),
+                (3, 0x08, "text_wrapped"),
+                (4, 0x70, "vert_align"),
+            ),
         )
         upkbits(
             xf.alignment,
             pkd_align2,
-            ((0, 0x0F, "indent_level"), (4, 0x10, "shrink_to_fit"), (6, 0xC0, "text_direction"),),
+            (
+                (0, 0x0F, "indent_level"),
+                (4, 0x10, "shrink_to_fit"),
+                (6, 0xC0, "text_direction"),
+            ),
         )
         reg = pkd_used >> 2
         attr_stems = [
@@ -950,7 +963,10 @@ def handle_xf(self, data):
         upkbits(
             xf.background,
             pkd_brdbkg3,
-            ((0, 0x007F, "pattern_colour_index"), (7, 0x3F80, "background_colour_index"),),
+            (
+                (0, 0x007F, "pattern_colour_index"),
+                (7, 0x3F80, "background_colour_index"),
+            ),
         )
     elif bv >= 50:
         unpack_fmt = "<HHHBBIi"
@@ -964,7 +980,12 @@ def handle_xf(self, data):
             pkd_brdbkg2,
         ) = unpack(unpack_fmt, data[0:16])
         upkbits(
-            xf.protection, pkd_type_par, ((0, 0x01, "cell_locked"), (1, 0x02, "formula_hidden"),)
+            xf.protection,
+            pkd_type_par,
+            (
+                (0, 0x01, "cell_locked"),
+                (1, 0x02, "formula_hidden"),
+            ),
         )
         upkbits(
             xf,
@@ -978,7 +999,11 @@ def handle_xf(self, data):
         upkbits(
             xf.alignment,
             pkd_align1,
-            ((0, 0x07, "hor_align"), (3, 0x08, "text_wrapped"), (4, 0x70, "vert_align"),),
+            (
+                (0, 0x07, "hor_align"),
+                (3, 0x08, "text_wrapped"),
+                (4, 0x70, "vert_align"),
+            ),
         )
         orientation = pkd_orient_used & 0x03
         xf.alignment.rotation = [0, 255, 90, 180][orientation]
@@ -1007,7 +1032,10 @@ def handle_xf(self, data):
         upkbitsL(
             xf.border,
             pkd_brdbkg1,
-            ((22, 0x01C00000, "bottom_line_style"), (25, 0xFE000000, "bottom_colour_index"),),
+            (
+                (22, 0x01C00000, "bottom_line_style"),
+                (25, 0xFE000000, "bottom_colour_index"),
+            ),
         )
         upkbits(
             xf.border,
@@ -1033,7 +1061,12 @@ def handle_xf(self, data):
             pkd_brd_34,
         ) = unpack(unpack_fmt, data[0:12])
         upkbits(
-            xf.protection, pkd_type_par, ((0, 0x01, "cell_locked"), (1, 0x02, "formula_hidden"),)
+            xf.protection,
+            pkd_type_par,
+            (
+                (0, 0x01, "cell_locked"),
+                (1, 0x02, "formula_hidden"),
+            ),
         )
         upkbits(
             xf,
@@ -1047,7 +1080,11 @@ def handle_xf(self, data):
         upkbits(
             xf.alignment,
             pkd_align_orient,
-            ((0, 0x07, "hor_align"), (3, 0x08, "text_wrapped"), (4, 0x30, "vert_align"),),
+            (
+                (0, 0x07, "hor_align"),
+                (3, 0x08, "text_wrapped"),
+                (4, 0x30, "vert_align"),
+            ),
         )
         orientation = (pkd_align_orient & 0xC0) >> 6
         xf.alignment.rotation = [0, 255, 90, 180][orientation]
@@ -1099,14 +1136,29 @@ def handle_xf(self, data):
             pkd_brd_34,
         ) = unpack(unpack_fmt, data[0:12])
         upkbits(
-            xf.protection, pkd_type_prot, ((0, 0x01, "cell_locked"), (1, 0x02, "formula_hidden"),)
+            xf.protection,
+            pkd_type_prot,
+            (
+                (0, 0x01, "cell_locked"),
+                (1, 0x02, "formula_hidden"),
+            ),
         )
         upkbits(
             xf,
             pkd_type_prot,
-            ((2, 0x0004, "is_style"), (3, 0x0008, "lotus_123_prefix"),),  # Meaning is not known.
+            (
+                (2, 0x0004, "is_style"),
+                (3, 0x0008, "lotus_123_prefix"),
+            ),  # Meaning is not known.
+        )
+        upkbits(
+            xf.alignment,
+            pkd_align_par,
+            (
+                (0, 0x07, "hor_align"),
+                (3, 0x08, "text_wrapped"),
+            ),
         )
-        upkbits(xf.alignment, pkd_align_par, ((0, 0x07, "hor_align"), (3, 0x08, "text_wrapped"),))
         upkbits(xf, pkd_align_par, ((4, 0xFFF0, "parent_style_index"),))
         reg = pkd_used >> 2
         attr_stems = [
@@ -1153,7 +1205,14 @@ def handle_xf(self, data):
         ## all XF references in cell records :-(
         (xf.font_index, format_etc, halign_etc) = unpack("<BxBB", data)
         xf.format_key = format_etc & 0x3F
-        upkbits(xf.protection, format_etc, ((6, 0x40, "cell_locked"), (7, 0x80, "formula_hidden"),))
+        upkbits(
+            xf.protection,
+            format_etc,
+            (
+                (6, 0x40, "cell_locked"),
+                (7, 0x80, "formula_hidden"),
+            ),
+        )
         upkbits(xf.alignment, halign_etc, ((0, 0x07, "hor_align"),))
         for mask, side in ((0x08, "left"), (0x10, "right"), (0x20, "top"), (0x40, "bottom")):
             if halign_etc & mask:
@@ -1191,7 +1250,9 @@ def handle_xf(self, data):
     self.xfcount += 1
     if blah:
         xf.dump(
-            self.logfile, header="--- handle_xf: xf[%d] ---" % xf.xf_index, footer=" ",
+            self.logfile,
+            header="--- handle_xf: xf[%d] ---" % xf.xf_index,
+            footer=" ",
         )
     try:
         fmt = self.format_map[xf.format_key]
