@@ -3,7 +3,7 @@
 # This module is part of the excelrd package, which is released under a BSD-style licence.
 ##
 
-
+import io
 import re
 import sys
 from os.path import join, normpath
@@ -33,8 +33,10 @@ ET_has_iterparse = False
 
 def ensure_elementtree_imported(verbosity, logfile):
     global ET, ET_has_iterparse
+
     if ET is not None:
         return
+
     if "IronPython" in sys.version:
         import xml.etree.ElementTree as ET
 
@@ -45,23 +47,12 @@ def ensure_elementtree_imported(verbosity, logfile):
             import defusedxml.cElementTree as ET
         except ImportError:
             try:
-                import xml.etree.cElementTree as ET
+                import lxml.etree as ET
             except ImportError:
-                try:
-                    import cElementTree as ET
-                except ImportError:
-                    try:
-                        import lxml.etree as ET
-                    except ImportError:
-                        try:
-                            import xml.etree.ElementTree as ET
-                        except ImportError:
-                            try:
-                                import elementtree.ElementTree as ET
-                            except ImportError:
-                                raise Exception("Failed to import an ElementTree implementation")
+                import xml.etree.ElementTree as ET
+
     if hasattr(ET, "iterparse"):
-        _dummy_stream = BYTES_IO(b"")
+        _dummy_stream = io.BytesIO(b"")
         try:
             ET.iterparse(_dummy_stream)
             ET_has_iterparse = True
@@ -126,7 +117,7 @@ def cell_name_to_rowx_colx(cell_name, letter_value=_UPPERCASE_1_REL_INDEX, allow
                     assert 0 <= colx < X12_MAX_COLS
                     break
     except KeyError:
-        raise Exception("Unexpected character %r in cell name %r" % (c, cell_name))
+        raise Exception(f"Unexpected character {c!r} in cell name {cell_name!r}")
     rowx = int(cell_name[charx:]) - 1
     return rowx, colx
 
@@ -145,8 +136,8 @@ U_DC = "{http://purl.org/dc/elements/1.1/}"
 U_DCTERMS = "{http://purl.org/dc/terms/}"
 XML_SPACE_ATTR = "{http://www.w3.org/XML/1998/namespace}space"
 XML_WHITESPACE = "\t\n \r"
-X12_MAX_ROWS = 2 ** 20
-X12_MAX_COLS = 2 ** 14
+X12_MAX_ROWS = 2**20
+X12_MAX_COLS = 2**14
 V_TAG = U_SSML12 + "v"  # cell child: value
 F_TAG = U_SSML12 + "f"  # cell child: formula
 IS_TAG = U_SSML12 + "is"  # cell child: inline string
@@ -168,7 +159,7 @@ def cooked_text(self, elem):
         return ""
     if elem.get(XML_SPACE_ATTR) != "preserve":
         t = t.strip(XML_WHITESPACE)
-    return ensure_unicode(unescape(t))
+    return unescape(t)
 
 
 def get_text_from_si_or_is(self, elem, r_tag=U_SSML12 + "r", t_tag=U_SSML12 + "t"):
@@ -205,7 +196,8 @@ def map_attributes(amap, elem, obj):
 def cnv_ST_Xstring(s):
     if s is None:
         return ""
-    return ensure_unicode(s)
+
+    return s
 
 
 def cnv_xsd_unsignedInt(s):
@@ -227,34 +219,146 @@ def cnv_xsd_boolean(s):
 
 
 _defined_name_attribute_map = (
-    ("name", "name", cnv_ST_Xstring,),
-    ("comment", "", cnv_ST_Xstring,),
-    ("customMenu", "", cnv_ST_Xstring,),
-    ("description", "", cnv_ST_Xstring,),
-    ("help", "", cnv_ST_Xstring,),
-    ("statusBar", "", cnv_ST_Xstring,),
-    ("localSheetId", "scope", cnv_xsd_unsignedInt,),
-    ("hidden", "hidden", cnv_xsd_boolean,),
-    ("function", "func", cnv_xsd_boolean,),
-    ("vbProcedure", "vbasic", cnv_xsd_boolean,),
-    ("xlm", "macro", cnv_xsd_boolean,),
-    ("functionGroupId", "funcgroup", cnv_xsd_unsignedInt,),
-    ("shortcutKey", "", cnv_ST_Xstring,),
-    ("publishToServer", "", cnv_xsd_boolean,),
-    ("workbookParameter", "", cnv_xsd_boolean,),
-    ("", "any_err", 0,),
-    ("", "any_external", 0,),
-    ("", "any_rel", 0,),
-    ("", "basic_formula_len", 0,),
-    ("", "binary", 0,),
-    ("", "builtin", 0,),
-    ("", "complex", 0,),
-    ("", "evaluated", 0,),
-    ("", "excel_sheet_index", 0,),
-    ("", "excel_sheet_num", 0,),
-    ("", "option_flags", 0,),
-    ("", "result", None,),
-    ("", "stack", None,),
+    (
+        "name",
+        "name",
+        cnv_ST_Xstring,
+    ),
+    (
+        "comment",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "customMenu",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "description",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "help",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "statusBar",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "localSheetId",
+        "scope",
+        cnv_xsd_unsignedInt,
+    ),
+    (
+        "hidden",
+        "hidden",
+        cnv_xsd_boolean,
+    ),
+    (
+        "function",
+        "func",
+        cnv_xsd_boolean,
+    ),
+    (
+        "vbProcedure",
+        "vbasic",
+        cnv_xsd_boolean,
+    ),
+    (
+        "xlm",
+        "macro",
+        cnv_xsd_boolean,
+    ),
+    (
+        "functionGroupId",
+        "funcgroup",
+        cnv_xsd_unsignedInt,
+    ),
+    (
+        "shortcutKey",
+        "",
+        cnv_ST_Xstring,
+    ),
+    (
+        "publishToServer",
+        "",
+        cnv_xsd_boolean,
+    ),
+    (
+        "workbookParameter",
+        "",
+        cnv_xsd_boolean,
+    ),
+    (
+        "",
+        "any_err",
+        0,
+    ),
+    (
+        "",
+        "any_external",
+        0,
+    ),
+    (
+        "",
+        "any_rel",
+        0,
+    ),
+    (
+        "",
+        "basic_formula_len",
+        0,
+    ),
+    (
+        "",
+        "binary",
+        0,
+    ),
+    (
+        "",
+        "builtin",
+        0,
+    ),
+    (
+        "",
+        "complex",
+        0,
+    ),
+    (
+        "",
+        "evaluated",
+        0,
+    ),
+    (
+        "",
+        "excel_sheet_index",
+        0,
+    ),
+    (
+        "",
+        "excel_sheet_num",
+        0,
+    ),
+    (
+        "",
+        "option_flags",
+        0,
+    ),
+    (
+        "",
+        "result",
+        None,
+    ),
+    (
+        "",
+        "stack",
+        None,
+    ),
 )
 
 
@@ -267,7 +371,7 @@ def make_name_access_maps(bk):
         name_lcase = nobj.name.lower()
         key = (name_lcase, nobj.scope)
         if key in name_and_scope_map:
-            msg = "Duplicate entry %r in name_and_scope_map" % (key,)
+            msg = f"Duplicate entry {key!r} in name_and_scope_map"
             if 0:
                 raise XLRDError(msg)
             else:
@@ -287,7 +391,7 @@ def make_name_access_maps(bk):
     bk.name_map = name_map
 
 
-class X12General(object):
+class X12General:
     def process_stream(self, stream, heading=None):
         if self.verbosity >= 2 and heading is not None:
             fprintf(self.logfile, "\n=== %s ===\n", heading)
@@ -412,7 +516,7 @@ class X12Book(X12General):
         # print elem.attrib
         rid = elem.get(U_ODREL + "id")
         sheetId = int(elem.get("sheetId"))
-        name = unescape(ensure_unicode(elem.get("name")))
+        name = unescape(elem.get("name"))
         reltype = self.relid2reltype[rid]
         target = self.relid2path[rid]
         if self.verbosity >= 2:
@@ -526,7 +630,7 @@ class X12Styles(X12General):
         self.xf_type = 1
 
     def do_numfmt(self, elem):
-        formatCode = ensure_unicode(elem.get("formatCode"))
+        formatCode = elem.get("formatCode")
         numFmtId = int(elem.get("numFmtId"))
         is_date = is_date_format_string(self.bk, formatCode)
         self.fmt_is_date[numFmtId] = is_date
@@ -708,9 +812,9 @@ class X12Sheet(X12General):
                             assert 0 <= colx < X12_MAX_COLS
                             break
                 except KeyError:
-                    raise Exception("Unexpected character %r in cell name %r" % (c, cell_name))
+                    raise Exception(f"Unexpected character {c!r} in cell name {cell_name!r}")
                 if explicit_row_number and cell_name[charx:] != row_number:
-                    raise Exception("cell name %r but row number is %r" % (cell_name, row_number))
+                    raise Exception(f"cell name {cell_name!r} but row number is {row_number!r}")
             xf_index = int(cell_elem.get("s", "0"))
             cell_type = cell_elem.get("t", "n")
             tvalue = None
